import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "@aws-cdk/cdk-assets-schema",
    "1.64.0",
    __name__[0:-6],
    "cdk-assets-schema@1.64.0.jsii.tgz",
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
